@@ -15,17 +15,20 @@ extern "C" {
 #endif /* __cplusplus */ 
 
 #include <openssl/bn.h>
+
 #include <libxml/tree.h> 
 
-BIGNUM*			xmlSecCryptoBinary2BN		(const xmlChar *str,
-							 BIGNUM **a);
-xmlChar*		xmlSecBN2CryptoBinary		(const BIGNUM *a);
+#include <xmlsec/xmlsec.h>
 
-BIGNUM*			xmlSecNodeGetBNValue		(const xmlNodePtr cur,
+XMLSEC_EXPORT BIGNUM*	xmlSecCryptoBinary2BN		(const xmlChar *str,
 							 BIGNUM **a);
-int			xmlSecNodeSetBNValue		(xmlNodePtr cur, 
+XMLSEC_EXPORT xmlChar*	xmlSecBN2CryptoBinary		(const BIGNUM *a);
+
+XMLSEC_EXPORT BIGNUM*	xmlSecNodeGetBNValue		(const xmlNodePtr cur,
+							 BIGNUM **a);
+XMLSEC_EXPORT int	xmlSecNodeSetBNValue		(xmlNodePtr cur, 
 							 const BIGNUM *a,
-							 int addLineBreak);
+							 int addLineBreaks);
 
 #ifdef __cplusplus
 }
