@@ -3,6 +3,6 @@
 #
 XMLSEC_LIBDIR="-L${libdir}"
 XMLSEC_LIBS="-lxmlsec -L/usr/lib -lxml2 -lz -lm"
-XMLSEC_INCLUDEDIR="-I${prefix}/include  -I/usr/include/libxml2/libxml -I/usr/include/libxml2"
-MODULE_VERSION="xmlsec-0.0.1"
+XMLSEC_INCLUDEDIR="-I${prefix}/include  -I/usr/include/libxml2"
+MODULE_VERSION="xmlsec-0.0.9"
 
